%ifarch %{ix86}
%bcond_without assembler
%else
%bcond_with assembler
%endif

# JIT in bundled libzpaq supported on x86 and x86_64 only, bug #1309772
%ifarch %{ix86} x86_64
%bcond_without jit
%else
%bcond_with jit
%endif

# These utilities do not use the standalone library
Name:           lrzip
Version:        0.616
Release:        5%{?dist}
Summary:        Compression program optimized for large files
Group:          Applications/File
License:        GPLv2+
URL:            http://ck.kolivas.org/apps/%{name}/
Source0:        %{url}%{name}-%{version}.tar.bz2
# Fix GCC 6 warnings, bug #1306292,
# <https://github.com/ckolivas/lrzip/issues/46>
Patch0:         lrzip-0.616-Cast-negative-values-in-models-definiton.patch
BuildRequires:  bash
BuildRequires:  bzip2-devel
BuildRequires:  coreutils
BuildRequires:  findutils
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  glibc-common
BuildRequires:  lzo-devel
BuildRequires:  make
BuildRequires:  %{_bindir}/pod2man
BuildRequires:  zlib-devel
%if %{with assembler}
BuildRequires:  nasm
%endif
# Bash completion support packaged as sub-package removed in 0.608
Obsoletes:      %{name}-bash < 0.608-1
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

%description
Long Range ZIP or Lzma RZIP

This is a compression program optimized for large files. The larger the file
and the more memory you have, the better the compression advantage this will
provide, especially once the files are larger than 100 MB. The advantage can
be chosen to be either size (much smaller than bzip2) or speed (much faster
than bzip2). Decompression is always much faster than bzip2.


%package libs
Summary:        Long Range ZIP library
Group:          System Environment/Libraries

%description libs
Dynamic library implementing Long Range ZIP or Lzma RZIP algorithm and archive
format.


%package devel
Summary:        Development files for Long Range ZIP library
Group:          Development/Libraries
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

%description devel
Files needed to develop application using Long Range ZIP library.


%package static
Summary:        Static Long Range ZIP library
Group:          Development/Libraries
Requires:       %{name}-devel%{?_isa} = %{version}-%{release}

%description static
Static library implementing Long Range ZIP or Lzma RZIP algorithm and archive
format.


%prep
%setup -q
%patch0 -p1
for F in lzma/history.txt; do
    iconv -f ISO-8859-1 -t UTF-8 < "$F" > "${F}.utf8"
    touch -r "$F" "${F}.utf8"
    mv "${F}.utf8" "$F"
done


%global docdir %{?_pkgdocdir}%{!?_pkgdocdir:%{_docdir}/%{name}-%{version}}
%build
%configure \
    --docdir='%{docdir}' --disable-doc \
    --enable-shared --enable-static --disable-static-bin \
    --%{?with_assembler:enable}%{!?with_assembler:disable}-asm \
    --enable-largefile %{!?with_jit:CPPFLAGS="${CPPFLAGS} -DNOJIT"}
make %{?_smp_mflags}


%install
make install DESTDIR=$RPM_BUILD_ROOT
find $RPM_BUILD_ROOT -name '*.la' -exec rm {} +


%check
./lrzip -z COPYING
./lrzip -i COPYING.lrz
./lrzip -d -o COPYING.new COPYING.lrz
cmp COPYING COPYING.new
rm COPYING.new


%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig


%files
%{docdir}
%{_bindir}/*
%{_mandir}/man1/*.1.gz
%{_mandir}/man5/*.5.gz

%files libs
%doc COPYING
%{_libdir}/lib%{name}.so.*

%files devel
%doc decompress_demo.c liblrzip_demo.c
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/*

%files static
%{_libdir}/lib%{name}.a

%changelog
* Fri Feb 19 2016 Petr Pisar <ppisar@redhat.com> - 0.616-5
- Fix GCC 6 warnings (bug #1306292)
- Add a simple test
- Specify all dependencies
- Disable tests on ARM (bug #1309772)
- Enable JIT only on x86 and x86_64 architectures (bug #1309772)

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.616-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.616-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Sep 10 2013 Petr Pisar <ppisar@redhat.com> - 0.616-2
- Correct assembler usage

* Tue Sep 10 2013 Petr Pisar <ppisar@redhat.com> - 0.616-1
- 0.616 bump

* Mon Sep 02 2013 Petr Pisar <ppisar@redhat.com> - 0.615-1
- 0.615 bump

* Fri Jul 26 2013 Ville Skyttä <ville.skytta@iki.fi> - 0.614-4
- Install docs to %%{_pkgdocdir} where available.

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.614-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.614-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jul 13 2012 Petr Pisar <ppisar@redhat.com> - 0.614-1
- 0.614 bump

* Mon Jul 09 2012 Petr Pisar <ppisar@redhat.com> - 0.613-1
- 0.613 bump

* Mon Mar 19 2012 Petr Pisar <ppisar@redhat.com> - 0.612-1
- 0.612 bump

* Wed Mar 14 2012 Petr Pisar <ppisar@redhat.com> - 0.611-1
- 0.611 bump
- The lrzip implementation is available as standalone library now

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.608-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Sep 26 2011 Petr Pisar <ppisar@redhat.com> - 0.608-1
- 0.608 bump
- Obsolete lrzip-bash sub-package as upstream removed bash completion support

* Mon Sep 19 2011 Petr Pisar <ppisar@redhat.com> - 0.607-1
- 0.607 bump
- Fix bash completion installation
- Remove defattr spec code
- Package bash completion helper into standalone sub-package

* Mon May 16 2011 Petr Pisar <ppisar@redhat.com> - 0.606-1
- 0.606 bump

* Tue May 10 2011 Petr Pisar <ppisar@redhat.com> - 0.605-1
- 0.605 bump

* Wed Apr 27 2011 Petr Pisar <ppisar@redhat.com> - 0.604-1
- 0.604 bump

* Fri Apr 22 2011 Petr Pisar <ppisar@redhat.com> - 0.603-1
- 0.603 bump

* Thu Apr 14 2011 Petr Pisar <ppisar@redhat.com> - 0.602-1
- 0.602 bump

* Thu Mar 24 2011 Petr Pisar <ppisar@redhat.com> - 0.601-1
- 0.601 bump
- Fix symlink installation

* Wed Mar 23 2011 Petr Pisar <ppisar@redhat.com> - 0.600-1
- 0.600 bump
- Archives generated by this version are not backward compatible
- Fix manual pages generation
- Fix symlinks installation
- Recode non-UTF-8 documentation

* Tue Mar 08 2011 Petr Pisar <ppisar@redhat.com> - 0.571-1
- 0.571 bump

* Fri Feb 25 2011 Petr Pisar <ppisar@redhat.com> - 0.570-1
- 0.570 bump

* Mon Feb 21 2011 Petr Pisar <ppisar@redhat.com> - 0.560-1
- 0.560 bump

* Mon Feb 14 2011 Petr Pisar <ppisar@redhat.com> - 0.552-1
- 0.552 bump

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.551-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Dec 13 2010 Petr Pisar <ppisar@redhat.com> - 0.551-1
- 0.551 bump
- Upstream changed compresion level scale. Maximal level is 7 now.

* Thu Dec 09 2010 Petr Pisar <ppisar@redhat.com> - 0.544-1
- 0.544 bump

* Thu Dec 02 2010 Petr Pisar <ppisar@redhat.com> - 0.543-1
- 0.543 bump

* Tue Nov 23 2010 Petr Pisar <ppisar@redhat.com> - 0.542-1
- 0.542 bump

* Fri Nov 19 2010 Petr Pisar <ppisar@redhat.com> - 0.541-1
- 0.541 bump

* Mon Nov 01 2010 Petr Pisar <ppisar@redhat.com> - 0.47-1
- 0.47 bump
- Drop unneeded patches
- Remove obsolete BuildRoot

* Mon Aug  9 2010 Petr Pisar <ppisar@redhat.com> - 0.46-1
- 0.46 bump (bug #606722)
- Version 0.40 breaks backward compatibility (archive format)
- Fix package description spelling

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.23-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.23-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Jul 18 2008 Shawn Starr <spstarr@fedoraproject.org> 0.23-1
- New upstream release

* Fri Feb 08 2008 Warren Togami <wtogami@redhat.com> 0.19-1
- 0.19 and rebuild for gcc-4.3

* Mon Nov 12 2007 Warren Togami <wtogami@redhat.com> 0.18-1
- initial package
